Changelog
=========

`2.0a2`_
------

New features
~~~~~~~~~~~~

* Allow adding iCal widgets to dashboard
* Allow adding RSS widgets to dashboard

Bugfixes
~~~~~~~~

* None

Minor changes
~~~~~~~~~~~~~

* None

_`2.0a2`: https://edugit.org/AlekSIS/Official/AlekSIS-App-DashboardFeeds/-/tags/2.0a2
